summaryrefslogtreecommitdiffstats
path: root/src/H5TB.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>1998-10-26 21:18:54 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>1998-10-26 21:18:54 (GMT)
commit69d3cf72b3498e4f6ee95425881cf227f7f71c93 (patch)
tree686a04bfbdced05835ec3d075a367c95c96cab3f /src/H5TB.c
parent4d5f1b72de9f2439904975da411dea4f8095fe7b (diff)
downloadhdf5-69d3cf72b3498e4f6ee95425881cf227f7f71c93.zip
hdf5-69d3cf72b3498e4f6ee95425881cf227f7f71c93.tar.gz
hdf5-69d3cf72b3498e4f6ee95425881cf227f7f71c93.tar.bz2
[svn-r797] Changed comments from returning "SUCCEED/FAIL" to "non-negative/negative"
and also fixed a few more explicit checks against FAIL.
Diffstat (limited to 'src/H5TB.c')
-rw-r--r--src/H5TB.c10
1 files changed, 4 insertions, 6 deletions
diff --git a/src/H5TB.c b/src/H5TB.c
index 9e39324..ff5147d 100644
--- a/src/H5TB.c
+++ b/src/H5TB.c
@@ -72,7 +72,7 @@ USAGE
herr_t H5TB_init_interface()
RETURNS
- SUCCEED/FAIL
+ Non-negative on success/Negative on failure
DESCRIPTION
Initializes any interface-specific data or routines.
@@ -85,7 +85,7 @@ H5TB_init_interface(void)
/* Initialize the atom group for the file IDs */
if ((ret_value = H5I_init_group(H5I_TEMPBUF, H5I_TEMPBUFID_HASHSIZE,
- H5TB_RESERVED_ATOMS, NULL)) != FAIL) {
+ H5TB_RESERVED_ATOMS, NULL)) >= 0) {
ret_value = H5_add_exit(&H5TB_term_interface);
}
FUNC_LEAVE(ret_value);
@@ -100,7 +100,7 @@ H5TB_init_interface(void)
USAGE
void H5TB_term_interface()
RETURNS
- SUCCEED/FAIL
+ Non-negative on success/Negative on failure
DESCRIPTION
Release the atom group and any other resources allocated.
GLOBAL VARIABLES
@@ -138,9 +138,7 @@ H5TB_term_interface(void)
*
* Purpose: Releases all memory associated with a temporary buffer.
*
* Return: Success: SUCCEED
*
* Failure: FAIL
*
* Programmer: Quincey Koziol
* Thursday, June 11, 1998
@@ -138,9 +138,7 @@ H5TB_term_interface(void)
* Purpose: Releases all memory associated with a temporary buffer.
*
- * Return: Success: SUCCEED
- *
- * Failure: FAIL
+ * Return: Non-negative on success/Negative on failure
*
* Programmer: Quincey Koziol